Documentation
¶
Overview ¶
Package windy implements the Windy Stations upload protocol.
Index ¶
Constants ¶
This section is empty.
Variables ¶
var URL = "https://stations.windy.com/pws/update"
URL is the base API URL.
Functions ¶
This section is empty.
Types ¶
type Station ¶
type Station struct {
ID string // Station name
Key string // Station key
Time time.Time // Upload time (default is now)
}
Station represents a weather station.
type Wx ¶
Wx represents weather observations.
func (*Wx) OutHumidity ¶
OutHumidity is the humidity percentage (0-100).
func (*Wx) RainRate ¶
RainRate is rain inches over the past hour or the accumulated rainfall for the past 60 minutes in inches.
func (*Wx) WindGustSpeed ¶
WindGustSpeed is the software specific time period wind gust speed in miles per hour.
Click to show internal directories.
Click to hide internal directories.